==> catseye-fm-3.0.0.0.tar.gz: catseye-fm-3.0.0.0/listitems.h <==
/*
    Copyright 2007, 2008, 2009 Geyer Klaus

    This file is part of Cat'sEyE.

    Cat'sEyE is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    Cat'sEyE is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Cat'sEyE.  If not, see <http://www.gnu.org/licenses/>.
*/



#ifndef LISTITEMS_H_
#define LISTITEMS_H_

#define MAXTYPELENGTH 10                //the max length of the types (as they are searched for)
#define FIELDSIZE (3 * MAXTYPELENGTH)       //used in the struct below and to fill its variablse


struct FileAttributs{
	char type[FIELDSIZE];
	guint64 size;
	int owner;
	int group;
	char permission[FIELDSIZE];
	char accessed[FIELDSIZE];
	char changed[FIELDSIZE];
	int type_d;	//(4 = directory, 10=link) look man dirent, when it is link here stays how to tread hem (as file, as Directory)
	time_t	utaccessed;	//untouched timestamp from files
	time_t 	utchanged;
	gboolean hiddenfile;	//TRUE if hidden
	GString *gstrLinkTarget;    //only set when the item is a link
};

struct CallItemsToSystemStructure{
	GString *usercommand;
	GString *FileList;
	GString *WorkPath;
	GString *QuitReplyText; // in <options - block, property quitreply
	GString *ActionNoteText;    // in <options-block, property actionnote, != NULL if defined and may hold text to view as caption
	//GString *UpdateFolderWhenFinished; //in <options - block, the property folderupdate
	struct updateList *UpdateFolderWhenFinished_List;
	void *data; //used to store the list from call newusercommand via list
	gboolean bThreaded; //TRUE when callItemsToSystem is called as thread, and FALSE if it is not.
                        //We need this information: We rewrote our ViaList - function, therefore we need a synchronus systemcall
                        //but when callItemsToSystem exits with g_thread_exit(), out ListWIdget-thread will be terminated,
                        //this bool let us decide in callItemsToSystem wether to end it with g_thread_exit or return.
};


struct SearchItemStruct{
	GString *gstrSearchString;
	GtkTreeSelection *selection;
};


struct RecursiveSizeStructure{
	GtkWindow *mainWin;
	int *ibreak;	//to stop Operation  0=goOn...........	//free it
	GtkWidget *theLabel;
	GString *gstrPath;		//................   			//free it
	GString **gstrDPItems;  //................				//free it
	int ItemCounter;	//Number of items in gstrDPItems	//for cleanup
	int ItemStringCounter;	//Number of items stored completle in lists for strings, sizes and types
	guint64 *intPSizes;  //Sizes of the items;				//free it
	guint64 *intPTypes;	//Type of the items;				//free it
	int iReadyForCleanUp; 				//=0 if the calculate-Threads has not received  the ibreak=1 yet
	guint64 guint64_size; //holds the size in bytes of the Items;
	int SideObjectOrFileshelfItem;	//0=SideObject, 1=Fileshelf	used in getSizeOfSelectedItemsRecursive to decide if we need to build directoryString
	int ErrorOccured;   //becomes 1, when there was an error opening a directory. Its 0, when no error occured
};

void CopyReMoveItemsViaList(void *data);
int isValidDirectory(char *cpDirectory);
int openDirectory(DIR **Directory, int *DirectoryOpened, GString *dirname);
void getNextListItem( DIR *Directory, struct dirent **dirzeiger ,int DirectoryOpened, GString *str);
void closeDirectory(DIR **Directory);
int fileAttributesGet(struct dirent *dirzeiger, int DirectoryOpened, struct FileAttributs *attribs,char *path, char *name);
//void deleteFileViaList(void *data);
//void copyItemsViaList(void *data);
//void moveItemsViaList(void *data);
int moveItems(char *Source, char* DestinationPath);
int makeDirectory(char *Directory, int iShowErrorMessage, GString *gstrErrorStorage);
void callItemsToSystem(void *data);
int getDirectorySize(guint64 *size, GString *gstrDirectory, int *ibreak);
void getSizeOfSelectedItemsRecursive_dialog(void *data);
void markItemsWithSameType(GtkTreeView *treeview, int ColType);
gboolean mySelectAllFunction( GtkTreeView *treeview, gpointer user_data);

#endif /*LISTITEMS_H_*/

==> catseye-fm-4.2.0.0.tar.gz: catseye-fm-4.2.0.0/listitems.h <==
/*
    Copyright 2007, 2008, 2009, 2010 Geyer Klaus

    This file is part of Cat'sEyE.

    Cat'sEyE is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    Cat'sEyE is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Cat'sEyE.  If not, see <http://www.gnu.org/licenses/>.
*/



#ifndef LISTITEMS_H_
#define LISTITEMS_H_

#define MAXTYPELENGTH 10                //the max length of the types (as they are searched for)
#define FIELDSIZE (3 * MAXTYPELENGTH)       //used in the struct below and to fill its variablse


struct FileAttributs{
	char type[FIELDSIZE];
	guint64 size;
	int owner;
	int group;
	char permission[FIELDSIZE];
	char accessed[FIELDSIZE];
	char changed[FIELDSIZE];
	int type_d;	//(4 = directory, 10=link) look man dirent, when it is link here stays how to tread hem (as file, as Directory)
	time_t	utaccessed;	//untouched timestamp from files
	time_t 	utchanged;
	gboolean hiddenfile;	//TRUE if hidden
	GString *gstrLinkTarget;    //only set when the item is a link
};


struct SearchItemStruct{
	GString *gstrSearchString;
	GtkTreeSelection *selection;
};


struct RecursiveSizeStructure{
	GtkWindow *mainWin;
	int *ibreak;	//to stop Operation  0=goOn...........	//free it
	GtkWidget *theLabel;
	GString *gstrPath;		//................   			//free it
	GString **gstrDPItems;  //................				//free it
	int ItemCounter;	//Number of items in gstrDPItems	//for cleanup
	int ItemStringCounter;	//Number of items stored completle in lists for strings, sizes and types
	guint64 *intPSizes;  //Sizes of the items;				//free it
	guint64 *intPTypes;	//Type of the items;				//free it
	int iReadyForCleanUp; 				//=0 if the calculate-Threads has not received  the ibreak=1 yet
	guint64 guint64_size; //holds the size in bytes of the Items;
	int SideObjectOrFileshelfItem;	//0=SideObject, 1=Fileshelf	used in getSizeOfSelectedItemsRecursive to decide if we need to build directoryString
	int ErrorOccured;   //becomes 1, when there was an error opening a directory. Its 0, when no error occured
};


struct myLocationStruct {
    GString *gstrLocation;
    GError  *error;
    GFile   *gfileLocation;
    GFileEnumerator *enumerator;
    GFileInfo *gfileInfo;
};


void markedNamesToClipboard(GtkTreeView *TreeView, gboolean bWithPath, int iColumnName, int iColumnPath, char *cpPath);
void CopyReMoveItemsViaList(void *data);
void CopyReMoveItemsViaList_SizeCalc (void *data);
int isValidDirectory(char *cpDirectory);
int openLocation (char *cpLocation, struct myLocationStruct *struLocation, gboolean bUseMessageWidgets, gboolean bMakeThreadSave);
int getNextItemInLocation(struct myLocationStruct *struLocation, GString *gstrName, gboolean bUseMessageWidgets, gboolean bMakeThreadSave);
int closeLocation (struct myLocationStruct *struLocation);
int fileAttributesGet(struct FileAttributs *attribs,char *path, char *name);
int makeDirectory(char *Directory, int iShowErrorMessage, GString *gstrErrorStorage);
void callItemsToSystem(void *data);
int getDirectorySize(guint64 *size, GString *gstrDirectory, int *ibreak, gboolean bFollowLinks);
void getSizeOfSelectedItemsRecursive_dialog(void *data);
void markItemsWithSameType(GtkTreeView *treeview, int ColType);
gboolean mySelectAllFunction( GtkTreeView *treeview, gpointer user_data);

#endif /*LISTITEMS_H_*/
